pub struct BoundingBox {
pub min_x: f64,
pub min_y: f64,
pub max_x: f64,
pub max_y: f64,
}Expand description
A bounding box defined by minimum and maximum coordinates.
Fields
min_x: f64Minimum X coordinate
min_y: f64Minimum Y coordinate
max_x: f64Maximum X coordinate
max_y: f64Maximum Y coordinate
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn from_coordinates(c1: Coordinate, c2: Coordinate) -> Result<Self>
pub fn from_coordinates(c1: Coordinate, c2: Coordinate) -> Result<Self>
Creates a bounding box from two coordinates.
Sourcepub fn center(&self) -> Coordinate
pub fn center(&self) -> Coordinate
Returns the center coordinate of the bounding box.
Sourcepub fn corners(&self) -> [Coordinate; 4]
pub fn corners(&self) -> [Coordinate; 4]
Returns the four corner coordinates.
Sourcepub fn contains(&self, coord: &Coordinate) -> bool
pub fn contains(&self, coord: &Coordinate) -> bool
Checks if a coordinate is within the bounding box.
Sourcepub fn expand_to_include(&mut self, coord: &Coordinate)
pub fn expand_to_include(&mut self, coord: &Coordinate)
Expands the bounding box to include a coordinate.